# Picatrix

[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/google/picatrix/blob/main/notebooks/Quick_Primer_on_Colab_Jupyter.ipynb)

This repository will in the future host configuration files, and libraries
for use with a Jupyter notebook or colab in order to facilitate work for
incident responders or those working on detection.

You can also join the slack channel [here](http://join-open-source-dfir-slack.herokuapp.com/), the channel for picatrix is #picatrix. 

Stay tuned for some content being uploaded here.
